@@ -1,6 +1,7 @@
 ;;; speechd-braille.el --- Emacs braille emulator driver
 
 ;; Copyright (C) 2004, 2005, 2006, 2008 Brailcom, o.p.s.
+;; Copyright (C) 2012 Milan Zamazal
 
 ;; Author: Milan Zamazal <pdm@brailcom.org>
 
@@ -116,9 +117,14 @@
 
 (defclass speechd-braille-emu-driver (speechd-driver)
   ((name :initform 'braille-emu)
-   (manager :initform (lambda () (speechd-braille--create-manager
-                                  #'speechd-braille--display)))
-   (priority :initform (lambda () speechd-default-text-priority))))
+  (manager)
+  (priority)))
+
+(defmethod initialize-instance :after
+    ((this speechd-braille-emu-driver) slots)
+  (progn
+    (oset this priority speechd-default-text-priority)
+    (oset this manager (speechd-braille--create-manager #'speechd-braille--display))))
 
 (defmethod speechd-braille--make-message
     ((driver speechd-braille-emu-driver) text cursor)
@@ -163,7 +169,7 @@
      driver text (speechd-braille--make-message driver text nil))))
 
 (defmethod speechd.key ((driver speechd-braille-emu-driver) key)
-  (let ((key-string (format (if (numberp key) "%c" "%s") key)))
+  (let ((key-string (if (numberp key) (key-description (list key)) (format "%s" key))))
     (speechd-braille--maybe-enqueue
      driver key-string (speechd-braille--make-message driver key-string nil))))
 
