@@ -1,6 +1,7 @@
 ;;; speechd.el --- Library for accessing Speech Dispatcher
 
 ;; Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2010 Brailcom, o.p.s.
+;; Copyright (C) 2012 Milan Zamazal
 
 ;; Author: Milan Zamazal <pdm@brailcom.org>
 
@@ -55,7 +56,8 @@
 Possible values are `unix-socket' for Unix domain sockets and
 `inet-socket' for Internet sockets on a given host and port (see
 `speechd-host' and `speechd-port' variables)."
-  :type 'symbol
+  :type '(choice (const :tag "Unix domain socket" unix-socket)
+                 (const :tag "Internet socket" inet-socket))
   :group 'speechd)
 
 (defcustom speechd-host (or (getenv "SPEECHD_HOST") "localhost")
@@ -504,7 +506,7 @@ current voice."
 				     'raw-text))
 	(if (fboundp 'set-process-query-on-exit-flag)
 	    (set-process-query-on-exit-flag process nil)
-	  (process-kill-without-query process))
+	  (set-process-query-on-exit-flag process nil))
 	(set-process-filter process #'speechd--process-filter))
       process)))
 
@@ -658,7 +660,7 @@ If QUIET is non-nil, don't echo success report."
 	(number-of-failures 0))
     (maphash #'(lambda (name _)
 		 (let ((speechd-client-name name))
-		   (if (speechd-open :quiet t :force-reopen t)
+		   (if (speechd-open nil :quiet t :force-reopen t)
 		       (incf number-of-connections)
 		     (incf number-of-failures))))
 	     speechd--connections)
